from .kanjidic2_dataclass import Kanji_CharacterStandard, Kanji_Radical, Kanji_Description_Variant, Kanji_RNM_group, \
    Kanji_Description, Kanji_DictionaryNumber, Kanji_QueryCode, Kanji_RNM_Reading, Kanji_RNM_Meaning, Kanji_RNM, Kanji
from .jmdict_dataclass import Entry, Entry_Sense, Entry_Sense_Gloss, Entry_SourceLanguage, \
    Entry_KanjiElement, Entry_ReadingElement
from .get_error_wrapper import get_empty_error
